---
title: Article title
keywords: keyword1, keyword2
desc: article description
---

## Add article

* Create markdown file with file name end with `.md` in the directory of this file, e.g. `first.md`
* Add link in `sidebar.yaml`

```markdown
items:
-   label: Brief
    file: README.md
-   label: First
    file: first.md
```

## More example

More visit: [teedoc.neucrack.com](https://teedoc.neucrack.com/) or [teedoc.github.io](https://teedoc.github.io/)

And more example see: [github.com/teedoc/teedoc.github.io](https://github.com/teedoc/teedoc.github.io) and [https://github.com/teedoc/template](https://github.com/teedoc/template) , and [sipeed wiki](https://github.com/sipeed/sipeed_wiki)

